@@ -61,7 +61,7 @@ def send_log_email_with_msg(email, msg):
                                            'Email_Content', 'Signature',
                                            'Email_Us', 'FAQ_URL',
                                            'Unsubscribe_Email_ID',
-                                           'Content_Type'
+                                           'Content_Type', 'Banner'
                                            ).first()
         if email_configuration:
             send_notifications_with_msg(email, sender,
