@@ -35,7 +35,8 @@ def send_notifications(email, sender, email_configuration):
         email_us=email_configuration.get('Email_Us'),
         faq_url=email_configuration.get('FAQ_URL'),
         unsubscribe=email_configuration.get('Unsubscribe_Email_ID'),
-        banner="http://localhost:8000/" + email_configuration.get('Banner'))
+        banner=email_configuration.get('Banner'))
+    # banner="http://localhost:8000/" + email_configuration.Banner.url)
     # Define the attachment part and encode it using MIMEApplication.
     att = MIMEApplication(open(ATTACHMENT, 'rb').read())
 
@@ -84,7 +85,7 @@ def send_notifications_with_msg(email, sender, msg, email_configuration):
         email_us=email_configuration.get('Email_Us'),
         faq_url=email_configuration.get('FAQ_URL'),
         unsubscribe=email_configuration.get('Unsubscribe_Email_ID'),
-        banner="http://localhost:8000/" + email_configuration.get('Banner'))
+        banner=email_configuration.get('Banner'))
 
     for each_recipient in RECIPIENT:
         try:
